@@ -42,11 +42,11 @@ def getVivisectLibraryVersion():
 
 
 def setVwVivisectLibraryVersion(vw):
-    vw.config.getSubConfig('viv')['version'] = getVivisectLibraryVersion()
+    vw.setMeta("version", getVivisectLibraryVersion())
 
 
 def getVwVivisectLibraryVersion(vw):
-    return vw.config.getSubConfig('viv').get('version')
+    return vw.getMeta("version")
 
 
 def assertVwMatchesVivisectLibrary(vw):
@@ -186,7 +186,7 @@ class BasicBlock(LoggingObject):
             try:
                 o = self.vw.parseOpcode(va)
             except Exception as e:
-                self.d("Failed to disassemble: %s: %s", hex(va), e.message)
+                self.d("Failed to disassemble: %s: %s", hex(va), e)
                 break
             ret.append(o)
             va += len(o)
